# This Build.PL for POE-Component-IRC-Plugin-WWW-Reddit-TIL was generated by Dist::Zilla::Plugin::ModuleBuildTiny 0.015.
use strict;
use warnings;

use 5.010;
use Module::Build::Tiny 0.034;
Build_PL();
